Function syntax::ast_util::is_by_value_unopUnstable
[-] [+]
[src]
pub fn is_by_value_unop(u: UnOp) -> bool
Returns true if the unary operator takes its argument by value
pub fn is_by_value_unop(u: UnOp) -> bool
Returns true if the unary operator takes its argument by value
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).