Function syntax::ast_util::lit_is_strUnstable
[-] [+]
[src]
pub fn lit_is_str(lit: &Lit) -> bool
Returns true if this literal is a string and false otherwise.
pub fn lit_is_str(lit: &Lit) -> bool
Returns true if this literal is a string and false otherwise.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).